ReportRange class

Constructors

ReportRange({required int rowIndex, required int columnIndex, required int rowSpan, required int colSpan})
const
ReportRange.fromIndexes({required int startRowIndex, required int startColumnIndex, required int endRowIndex, required int endColumnIndex})
const
ReportRange.single({required int rowIndex, required int columnIndex})
const

Properties

colSpan → int
final
columnIndex → int
final
endColumnIndex → int
no setter
endRowIndex → int
no setter
hashCode → int
The hash code for this object.
no setteroverride
rowIndex → int
final
rowSpan → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({int? rowIndex, int? columnIndex, int? rowSpan, int? colSpan}) → ReportRange
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
shiftColumnsBy(int columns) → ReportRange
shiftRowsBy(int rows) → ReportRange
toString() → String
A string representation of this object.
override

Operators

operator +(ReportRange other) → ReportRange
operator ==(Object other) → bool
The equality operator.
override